.. _head_pose.ipd:

Inter-Pupillary Distance (IPD)
===============================

.. automodule:: eyetrace.head_pose.ipd
   :members:
   :undoc-members:
   :show-inheritance:

Calculates the Euclidean distance between the centers of the left and right pupils.
Useful for biometric purposes or scaling.